1.0.0 API documentation: matrix_query.hpp Source File

| 1.0.0 API documentation

matrix_query.hpp
Go to the documentation of this file.
1
14 #pragma once
15
16 // Dependency:
17 #include "../glm.hpp"
18 #include "../gtx/vector_query.hpp"
19 #include <limits>
20
21 #ifndef GLM_ENABLE_EXPERIMENTAL
22 # error "GLM: GLM_GTX_matrix_query is an experimental extension and may change in the future. Use #define GLM_ENABLE_EXPERIMENTAL before including it, if you really want to use it."
23 #elif GLM_MESSAGES == GLM_ENABLE && !defined(GLM_EXT_INCLUDED)
24 # pragma message("GLM: GLM_GTX_matrix_query extension included")
25 #endif
26
27 namespace glm
28 {
31
34 template<typename T, qualifier Q>
35 GLM_FUNC_DECL bool isNull(mat<2, 2, T, Q> const& m, T const& epsilon);
36
39 template<typename T, qualifier Q>
40 GLM_FUNC_DECL bool isNull(mat<3, 3, T, Q> const& m, T const& epsilon);
41
44 template<typename T, qualifier Q>
45 GLM_FUNC_DECL bool isNull(mat<4, 4, T, Q> const& m, T const& epsilon);
46
49 template<length_t C, length_t R, typename T, qualifier Q, template<length_t, length_t, typename, qualifier> class matType>
50 GLM_FUNC_DECL bool isIdentity(matType<C, R, T, Q> const& m, T const& epsilon);
51
54 template<typename T, qualifier Q>
55 GLM_FUNC_DECL bool isNormalized(mat<2, 2, T, Q> const& m, T const& epsilon);
56
59 template<typename T, qualifier Q>
60 GLM_FUNC_DECL bool isNormalized(mat<3, 3, T, Q> const& m, T const& epsilon);
61
64 template<typename T, qualifier Q>
65 GLM_FUNC_DECL bool isNormalized(mat<4, 4, T, Q> const& m, T const& epsilon);
66
69 template<length_t C, length_t R, typename T, qualifier Q, template<length_t, length_t, typename, qualifier> class matType>
70 GLM_FUNC_DECL bool isOrthogonal(matType<C, R, T, Q> const& m, T const& epsilon);
71
73 }//namespace glm
74
75 #include "matrix_query.inl"
glm::isNull
GLM_FUNC_DECL bool isNull(mat< 4, 4, T, Q > const &m, T const &epsilon)
Return whether a matrix is a null matrix.
glm::epsilon
GLM_FUNC_DECL GLM_CONSTEXPR genType epsilon()
Return the epsilon constant for floating point types.
glm::isIdentity
GLM_FUNC_DECL bool isIdentity(matType< C, R, T, Q > const &m, T const &epsilon)
Return whether a matrix is an identity matrix.
glm::isOrthogonal
GLM_FUNC_DECL bool isOrthogonal(matType< C, R, T, Q > const &m, T const &epsilon)
Return whether a matrix is an orthonormalized matrix.
glm::isNormalized
GLM_FUNC_DECL bool isNormalized(mat< 4, 4, T, Q > const &m, T const &epsilon)
Return whether a matrix is a normalized matrix.